summaryrefslogtreecommitdiffstats
path: root/src/core/hle/service/vi/display/vi_display.h
diff options
context:
space:
mode:
authorLioncash <mathew1800@gmail.com>2021-05-16 07:46:30 +0200
committerLioncash <mathew1800@gmail.com>2021-05-16 09:43:16 +0200
commit9a07ed53ebe4e27ef1a14e0469037cab9fb7b1e7 (patch)
tree54d6c5a6b319a10522b068caf2b0600c8f27876a /src/core/hle/service/vi/display/vi_display.h
parentMerge pull request #6316 from ameerj/title-fix (diff)
downloadyuzu-9a07ed53ebe4e27ef1a14e0469037cab9fb7b1e7.tar
yuzu-9a07ed53ebe4e27ef1a14e0469037cab9fb7b1e7.tar.gz
yuzu-9a07ed53ebe4e27ef1a14e0469037cab9fb7b1e7.tar.bz2
yuzu-9a07ed53ebe4e27ef1a14e0469037cab9fb7b1e7.tar.lz
yuzu-9a07ed53ebe4e27ef1a14e0469037cab9fb7b1e7.tar.xz
yuzu-9a07ed53ebe4e27ef1a14e0469037cab9fb7b1e7.tar.zst
yuzu-9a07ed53ebe4e27ef1a14e0469037cab9fb7b1e7.zip
Diffstat (limited to '')
-rw-r--r--src/core/hle/service/vi/display/vi_display.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/core/hle/service/vi/display/vi_display.h b/src/core/hle/service/vi/display/vi_display.h
index 388ce6083..166f2a4cc 100644
--- a/src/core/hle/service/vi/display/vi_display.h
+++ b/src/core/hle/service/vi/display/vi_display.h
@@ -32,14 +32,14 @@ public:
/// Constructs a display with a given unique ID and name.
///
/// @param id The unique ID for this display.
/// @param name The name for this display.
///
- Display(u64 id, std::string name, Core::System& system);
+ Display(u64 id, std::string name_, Core::System& system);
~Display();
/// Gets the unique ID assigned to this display.
u64 GetID() const {
- return id;
+ return display_id;
}
/// Gets the name of this display
@@ -96,7 +96,7 @@ public:
const Layer* FindLayer(u64 layer_id) const;
private:
- u64 id;
+ u64 display_id;
std::string name;
std::vector<std::shared_ptr<Layer>> layers;
@@ -32,14 +32,14 @@ public:
///
/// @param id The unique ID for this display.
- /// @param name The name for this display.
+ /// @param name_ The name for this display.
///